@@ -21,7 +21,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: ike-scan.c,v 1.86 2003/11/13 10:44:07 rsh Exp $
+ * $Id: ike-scan.c,v 1.88 2003/11/14 08:59:43 rsh Exp $
  *
  * ike-scan -- The IKE Scanner
  *
@@ -46,7 +46,7 @@
 
 #include "ike-scan.h"
 
-static char rcsid[] = "$Id: ike-scan.c,v 1.86 2003/11/13 10:44:07 rsh Exp $";   /* RCS ID for ident(1) */
+static char rcsid[] = "$Id: ike-scan.c,v 1.88 2003/11/14 08:59:43 rsh Exp $";   /* RCS ID for ident(1) */
 
 /* Global variables */
 struct host_entry *rrlist = NULL;	/* Round-robin linked list "the list" */
@@ -196,7 +196,7 @@ main(int argc, char *argv[]) {
    uint64_t host_timediff;	/* Time since last packet sent to this host */
    unsigned long end_timediff=0; /* Time since last packet received in ms */
    int req_interval;		/* Requested per-packet interval */
-   unsigned select_timeout;	/* Select timeout */
+   int select_timeout;		/* Select timeout */
    int cum_err=0;		/* Cumulative timing error */
    static int reset_cum_err;
    struct timeval start_time;	/* Program start time */
@@ -595,7 +595,10 @@ main(int argc, char *argv[]) {
  *	Note that there is no point calling advance_cursor() here because if
  *	host n is not ready to send, then host n+1 will not be ready either.
  */
-            select_timeout = cursor->timeout - host_timediff;
+            if (live_count)
+               select_timeout = cursor->timeout - host_timediff;
+            else
+               select_timeout = interval;
             reset_cum_err = 1;	/* Zero cumulative error */
          } /* End If */
       } else {		/* We can't send a packet yet */
@@ -1067,6 +1070,8 @@ recvfrom_wto(int s, char *buf, int len, struct sockaddr *saddr, int tmo) {
    int n;
    NET_SIZE_T saddr_len;
 
+   if (tmo < 0)
+     tmo = 0;	/* Negative timeouts not allowed */
    FD_ZERO(&readset);
    FD_SET(s, &readset);
    to.tv_sec  = tmo/1000000;
