@@ -21,7 +21,7 @@
  * You are encouraged to send comments, improvements or suggestions to
  * me at ike-scan@nta-monitor.com.
  *
- * $Id: ike-scan.h,v 1.40 2003/07/16 11:26:16 rsh Exp $
+ * $Id: ike-scan.h,v 1.51 2003/11/13 09:22:41 rsh Exp $
  *
  * ike-scan.h -- Header file for IKE Scanner (ike-scan)
  *
@@ -117,11 +117,12 @@
 #define DEFAULT_PATTERN_FUZZ 100	/* Default pattern fuzz in ms */
 #define DEFAULT_DH_GROUP 2		/* Default DH group for agg. mode */
 #define DEFAULT_IDTYPE ID_USER_FQDN	/* Default ID Type for agg. mode */
+#define DEFAULT_EXCHANGE_TYPE ISAKMP_XCHG_IDPROT	/* Main Mode */
 #define SYSLOG 1			/* Use syslog if defined */
 #define SYSLOG_FACILITY LOG_USER	/* Syslog facility to use */
 #define PATTERNS_FILE "ike-backoff-patterns" /* Backoff patterns filename */
 #define MAX_PAYLOAD 13			/* Maximum defined payload number */
-#define EXPECTED_TOTAL 100		/* Expected ISAKMP header size total */
+#define EXPECTED_TOTAL 72		/* Expected ISAKMP header size total */
 
 /* Structures */
 struct host_entry {
@@ -129,7 +130,7 @@ struct host_entry {
    struct host_entry *next;	/* Next pointer */
    unsigned n;			/* Ordinal number for this entry */
    struct in_addr addr;		/* Host IP address */
-   u_char live;			/* Set when awaiting response */
+   unsigned char live;		/* Set when awaiting response */
    struct timeval last_send_time; /* Time when last packet sent to this addr */
    struct time_list *recv_times; /* List of receive times */
    unsigned timeout;		/* Timeout for this host */
@@ -166,22 +167,40 @@ void info_syslog(const char *, ...);
 void err_print(int, int, const char *, va_list);
 char *cpystr(char *string);
 void usage(void);
-void add_host(char *);
-void send_packet(int, struct host_entry *);
+void add_host(char *, unsigned);
+void send_packet(int, struct host_entry *, int, struct timeval *);
 int recvfrom_wto(int, char *, int, struct sockaddr *, int);
 void remove_host(struct host_entry *);
 void timeval_diff(struct timeval *, struct timeval *, struct timeval *);
-void initialise_ike_packet(void);
+void initialise_ike_packet(unsigned, int, int, int, unsigned char *, int,
+                           int, int, int);
 struct host_entry *find_host_by_cookie(struct host_entry *, char *, int);
 void display_packet(int, char *, struct host_entry *, struct in_addr *);
 void advance_cursor(void);
 void decode_transform(char *, int, int);
 void dump_list(void);
-void dump_times(void);
+void dump_times(int);
 void add_recv_time(struct host_entry *);
-void add_pattern(char *);
+void add_pattern(char *, unsigned);
 char *match_pattern(struct host_entry *);
 int times_close_enough(struct timeval *, struct timeval *, unsigned);
-void dump_backoff(void);
+void dump_backoff(unsigned);
 void check_struct_sizes(void);
 unsigned int hstr_i(char *);
+struct isakmp_hdr* make_isakmp_hdr(uint8_t, uint8_t, uint32_t);
+struct isakmp_sa* make_sa_hdr(uint8_t, uint32_t);
+struct isakmp_proposal* make_prop(uint32_t, uint8_t);
+unsigned char* make_trans(int *, uint8_t, uint8_t, uint16_t,
+                          uint16_t, uint16_t, uint16_t, uint16_t,
+                          uint32_t);
+unsigned char* add_trans(int, int *, uint16_t, uint16_t, uint16_t, uint16_t,
+                         uint16_t, uint32_t);
+unsigned char* make_vid(int *, uint8_t, unsigned char *, int);
+unsigned char* add_vid(int, int *, unsigned char *, int);
+unsigned char* make_ke(int *, uint8_t, int);
+unsigned char* make_nonce(int *, uint8_t, int);
+unsigned char* make_id(int *, uint8_t, uint8_t, unsigned char *, int);
+int Gettimeofday(struct timeval *, struct timezone *);
+void *Malloc(size_t);
+void *Realloc(void *, size_t);
+void decode_trans(char *, int *, int *, int *, int *, int *);
